"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseClient = void 0;
const redirect_1 = require("./plugins/redirect");
const retry_1 = require("./plugins/retry");
const timeout_1 = require("./plugins/timeout");
class BaseClient {
    constructor() {
        this._headers = {};
        this._plugins = [];
    }
    auth(username, password) {
        const encoded = Buffer.from(username + ':' + password).toString('base64');
        this.set('Authorization', `Basic ${encoded}`);
        return this;
    }
    set(leader, value) {
        if (typeof leader === 'string') {
            this._headers[leader] = value;
        }
        else {
            Object.keys(leader).forEach((h) => this._headers[h] = leader[h]);
        }
        return this;
    }
    use(plugin) {
        this._plugins.push(plugin);
        return this;
    }
    timeout(ttl) {
        this.use((0, timeout_1.timeout)(ttl));
        return this;
    }
    retry(policy) {
        if (typeof policy === 'number') {
            this.use((0, retry_1.retry)({ retries: policy }));
        }
        else {
            this.use((0, retry_1.retry)(policy));
        }
        return this;
    }
    redirects(max_redirects) {
        this.use((0, redirect_1.redirect)(max_redirects));
        return this;
    }
}
exports.BaseClient = BaseClient;
